@@ -32,16 +32,17 @@ options:
   hostnames:
     description:
       - A list in order of precedence for hostname variables.
+      - The elements of the list can be a dict with the keys mentioned below or a string.
+      - Can be one of the options specified in U(http://docs.aws.amazon.com/cli/latest/reference/ec2/describe-instances.html#options).
+      - If value provided does not exist in the above options, it will be used as a literal string.
+      - To use tags as hostnames use the syntax tag:Name=Value to use the hostname Name_Value, or tag:Name to use the value of the Name tag.
     type: list
-    elements: dict
+    elements: raw
     default: []
     suboptions:
       name:
         description:
           - Name of the host.
-          - Can be one of the options specified in U(http://docs.aws.amazon.com/cli/latest/reference/ec2/describe-instances.html#options).
-          - To use tags as hostnames use the syntax tag:Name=Value to use the hostname Name_Value, or tag:Name to use the value of the Name tag.
-          - If value provided does not exist in the above options, it will be used as a literal string.
         type: str
         required: True
       prefix:
@@ -137,7 +138,10 @@ options:
     version_added: 3.1.0
   use_ssm_inventory:
     description:
-      - Add SSM inventory information into hostvars.
+      - Enables fetching additional EC2 instance information from the AWS Systems Manager (SSM) inventory service into hostvars.
+      - By leveraging the SSM inventory data, the I(use_ssm_inventory) option provides additional details and attributes
+        about the EC2 instances in your inventory. These details can include operating system information, installed software,
+        network configurations, and custom inventory attributes defined in SSM.
     type: bool
     default: False
     version_added: 6.0.0
@@ -153,9 +157,9 @@ regions:
 # Example using filters, ignoring permission errors, and specifying the hostname precedence
 plugin: amazon.aws.aws_ec2
 # The values for profile, access key, secret key and token can be hardcoded like:
-boto_profile: aws_profile
+profile: aws_profile
 # or you could use Jinja as:
-# boto_profile: "{{ lookup('env', 'AWS_PROFILE') | default('aws_profile', true) }}"
+# profile: "{{ lookup('env', 'AWS_PROFILE') | default('aws_profile', true) }}"
 # Populate inventory with instances in these regions
 regions:
   - us-east-1
@@ -239,7 +243,7 @@ exclude_filters:
 
 # Example using groups to assign the running hosts to a group based on vpc_id
 plugin: amazon.aws.aws_ec2
-boto_profile: aws_profile
+profile: aws_profile
 # Populate inventory with instances in these regions
 regions:
   - us-east-2
@@ -773,6 +777,9 @@ class InventoryModule(AWSInventoryBase):
         use_contrib_script_compatible_ec2_tag_keys = self.get_option("use_contrib_script_compatible_ec2_tag_keys")
         use_ssm_inventory = self.get_option("use_ssm_inventory")
 
+        if not all(isinstance(element, (dict, str)) for element in hostnames):
+            self.fail_aws("Hostnames should be a list of dict and str.")
+
         if self.get_option("include_extra_api_calls"):
             self.display.deprecate(
                 "The include_extra_api_calls option has been deprecated and will be removed in release 6.0.0.",
