@@ -35,7 +35,6 @@ options:
 
 extends_documentation_fragment:
     - azure.azcollection.azure
-    - azure.azcollection.azure_tags
 
 author:
     haiyuan_zhang (@haiyuazhang)
@@ -82,7 +81,6 @@ object_id:
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBase
 
 try:
-    from msrestazure.azure_exceptions import CloudError
     from azure.graphrbac.models import GraphErrorException
 except ImportError:
     # This is handled in azure_rm_common
@@ -104,7 +102,7 @@ class AzureRMADServicePrincipalInfo(AzureRMModuleBase):
         self.results = dict(changed=False)
 
         super(AzureRMADServicePrincipalInfo, self).__init__(derived_arg_spec=self.module_arg_spec,
-                                                            supports_check_mode=False,
+                                                            supports_check_mode=True,
                                                             supports_tags=False,
                                                             is_ad_resource=True)
 
