@@ -117,11 +117,9 @@ api_management_service:
             sample: null
 '''
 
-import time
 import json
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_rest import GenericRestClient
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
-from copy import deepcopy
 try:
     from msrestazure.azure_exceptions import CloudError
 except ImportError:
@@ -163,6 +161,7 @@ class AzureRMApiManagementServiceInfo(AzureRMModuleBaseExt):
             setattr(self, key, kwargs[key])
 
         self.mgmt_client = self.get_mgmt_svc_client(GenericRestClient,
+                                                    is_track2=True,
                                                     base_url=self._cloud_environment.endpoints.resource_manager)
 
         if (self.resource_group is not None and self.name is not None):
@@ -197,7 +196,7 @@ class AzureRMApiManagementServiceInfo(AzureRMModuleBaseExt):
                                               self.status_code,
                                               600,
                                               30)
-            results = json.loads(response.text)
+            results = json.loads(response.body())
         except CloudError as e:
             self.log('Could not get info for @(Model.ModuleOperationNameUpper).')
 
@@ -226,7 +225,7 @@ class AzureRMApiManagementServiceInfo(AzureRMModuleBaseExt):
                                               self.status_code,
                                               600,
                                               30)
-            results = json.loads(response.text)
+            results = json.loads(response.body())
         except CloudError as e:
             self.log('Could not get info for @(Model.ModuleOperationNameUpper).')
 
@@ -252,7 +251,7 @@ class AzureRMApiManagementServiceInfo(AzureRMModuleBaseExt):
                                               self.status_code,
                                               600,
                                               30)
-            results = json.loads(response.text)
+            results = json.loads(response.body())
         except CloudError as e:
             self.log('Could not get info for @(Model.ModuleOperationNameUpper).')
 
