@@ -26,6 +26,8 @@ options:
     tags:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
+        type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -88,7 +90,6 @@ from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common
 
 try:
     from azure.core.exceptions import ResourceNotFoundError
-    from msrestazure.azure_operation import AzureOperationPoller
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -114,7 +115,7 @@ class AzureRMApplicationSecurityGroupInfo(AzureRMModuleBase):
             name=dict(
                 type='str'
             ),
-            tags=dict(type='list')
+            tags=dict(type='list', elements='str')
         )
 
         self.resource_group = None
@@ -125,7 +126,8 @@ class AzureRMApplicationSecurityGroupInfo(AzureRMModuleBase):
 
         super(AzureRMApplicationSecurityGroupInfo, self).__init__(derived_arg_spec=self.module_arg_spec,
                                                                   supports_check_mode=True,
-                                                                  supports_tags=False)
+                                                                  supports_tags=False,
+                                                                  facts_module=True)
 
     def exec_module(self, **kwargs):
         """Main module execution method"""
