@@ -8,11 +8,6 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['preview'],
-                    'supported_by': 'community'}
-
-
 DOCUMENTATION = '''
 ---
 module: azure_rm_azurefirewall
@@ -243,8 +238,7 @@ EXAMPLES = '''
       key1: value1
     application_rule_collections:
       - priority: 110
-        action:
-          type: deny
+        action: deny
         rules:
           - name: rule1
             description: Deny inbound rule
@@ -259,8 +253,7 @@ EXAMPLES = '''
         name: apprulecoll
     nat_rule_collections:
       - priority: 112
-        action:
-          type: dnat
+        action: dnat
         rules:
           - name: DNAT-HTTPS-traffic
             description: D-NAT all outbound web traffic for inspection
@@ -277,8 +270,7 @@ EXAMPLES = '''
         name: natrulecoll
     network_rule_collections:
       - priority: 112
-        action:
-          type: deny
+        action: deny
         rules:
           - name: L4-traffic
             description: Block traffic based on source IPs and ports
@@ -322,10 +314,8 @@ id:
 
 import time
 import json
-import re
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_rest import GenericRestClient
-from copy import deepcopy
 try:
     from msrestazure.azure_exceptions import CloudError
 except ImportError:
@@ -567,7 +557,7 @@ class AzureRMAzureFirewalls(AzureRMModuleBaseExt):
                                                     supports_tags=True)
 
     def exec_module(self, **kwargs):
-        for key in list(self.module_arg_spec.keys()):
+        for key in list(self.module_arg_spec.keys()) + ['tags']:
             if hasattr(self, key):
                 setattr(self, key, kwargs[key])
             elif kwargs[key] is not None:
@@ -579,6 +569,7 @@ class AzureRMAzureFirewalls(AzureRMModuleBaseExt):
         response = None
 
         self.mgmt_client = self.get_mgmt_svc_client(GenericRestClient,
+                                                    is_track2=True,
                                                     base_url=self._cloud_environment.endpoints.resource_manager)
 
         resource_group = self.get_resource_group(self.resource_group)
@@ -674,9 +665,9 @@ class AzureRMAzureFirewalls(AzureRMModuleBaseExt):
             self.fail('Error creating the AzureFirewall instance: {0}'.format(str(exc)))
 
         try:
-            response = json.loads(response.text)
+            response = json.loads(response.body())
         except Exception:
-            response = {'text': response.text}
+            response = {'text': response.context['deserialized_data']}
 
         return response
 
@@ -709,7 +700,7 @@ class AzureRMAzureFirewalls(AzureRMModuleBaseExt):
                                               self.status_code,
                                               600,
                                               30)
-            response = json.loads(response.text)
+            response = json.loads(response.body())
             found = True
             self.log("Response : {0}".format(response))
             # self.log("AzureFirewall instance : {0} found".format(response.name))
