@@ -7,11 +7,6 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['preview'],
-                    'supported_by': 'community'}
-
-
 DOCUMENTATION = '''
 ---
 module: azure_rm_deployment
@@ -82,7 +77,7 @@ options:
     description:
         - If I(state=present), template will be created.
         - If I(state=present) and deployment exists, it will be updated.
-        - If I(state=absent), stack will be removed.
+        - If I(state=absent), the resource group will be removed.
     default: present
     choices:
         - present
@@ -407,17 +402,12 @@ deployment:
 import time
 
 try:
-    from azure.common.credentials import ServicePrincipalCredentials
     import time
-    import yaml
 except ImportError as exc:
     IMPORT_ERROR = "Error importing module prerequisites: %s" % exc
 
 try:
-    from itertools import chain
-    from azure.common.exceptions import CloudError
-    from azure.mgmt.resource.resources import ResourceManagementClient
-    from azure.mgmt.network import NetworkManagementClient
+    from azure.core.exceptions import ResourceNotFoundError
 
 except ImportError:
     # This is handled in azure_rm_common
@@ -503,7 +493,7 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
                     self.destroy_resource_group()
                     self.results['changed'] = True
                     self.results['msg'] = "deployment deleted"
-            except CloudError:
+            except Exception:
                 # resource group does not exist
                 pass
 
@@ -532,27 +522,26 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
                 uri=self.template_link
             )
 
-        if self.append_tags and self.tags:
-            try:
-                # fetch the RG directly (instead of using the base helper) since we don't want to exit if it's missing
-                rg = self.rm_client.resource_groups.get(self.resource_group)
-                if rg.tags:
-                    self.tags = dict(self.tags, **rg.tags)
-            except CloudError:
-                # resource group does not exist
-                pass
+        try:
+            # fetch the RG directly (instead of using the base helper) since we don't want to exit if it's missing
+            rg = self.rm_client.resource_groups.get(self.resource_group)
+            if rg.tags:
+                update_tags, self.tags = self.update_tags(rg.tags)
+        except ResourceNotFoundError:
+            # resource group does not exist
+            pass
 
         params = self.rm_models.ResourceGroup(location=self.location, tags=self.tags)
 
         try:
             self.rm_client.resource_groups.create_or_update(self.resource_group, params)
-        except CloudError as exc:
+        except Exception as exc:
             self.fail("Resource group create_or_update failed with status code: %s and message: %s" %
                       (exc.status_code, exc.message))
         try:
-            result = self.rm_client.deployments.create_or_update(self.resource_group,
-                                                                 self.name,
-                                                                 deploy_parameter)
+            result = self.rm_client.deployments.begin_create_or_update(self.resource_group,
+                                                                       self.name,
+                                                                       {'properties': deploy_parameter})
 
             deployment_result = None
             if self.wait_for_deployment_completion:
@@ -561,7 +550,7 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
                                                                                                                       'Succeeded']:
                     time.sleep(self.wait_for_deployment_polling_period)
                     deployment_result = self.rm_client.deployments.get(self.resource_group, self.name)
-        except CloudError as exc:
+        except Exception as exc:
             failed_deployment_operations = self._get_failed_deployment_operations(self.name)
             self.log("Deployment failed %s: %s" % (exc.status_code, exc.message))
             error_msg = self._error_msg_from_cloud_error(exc)
@@ -580,9 +569,9 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
         Destroy the targeted resource group
         """
         try:
-            result = self.rm_client.resource_groups.delete(self.resource_group)
+            result = self.rm_client.resource_groups.begin_delete(self.resource_group)
             result.wait()  # Blocking wait till the delete is finished
-        except CloudError as e:
+        except Exception as e:
             if e.status_code == 404 or e.status_code == 204:
                 return
             else:
@@ -600,7 +589,7 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
                     try:
                         nested_operations = self.rm_client.deployment_operations.list(self.resource_group,
                                                                                       nested_deployment)
-                    except CloudError as exc:
+                    except Exception as exc:
                         self.fail("List nested deployment operations failed with status code: %s and message: %s" %
                                   (exc.status_code, exc.message))
                     new_nested_operations = self._get_failed_nested_operations(nested_operations)
@@ -614,7 +603,7 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
 
         try:
             operations = self.rm_client.deployment_operations.list(self.resource_group, name)
-        except CloudError as exc:
+        except Exception as exc:
             self.fail("Get deployment failed with status code: %s and message: %s" %
                       (exc.status_code, exc.message))
         try:
@@ -687,9 +676,18 @@ class AzureRMDeploymentManager(AzureRMModuleBase):
         return ip_dict
 
     def _nic_to_public_ips_instance(self, nics):
+        nic_list = []
+        for nic in nics:
+            resp = None
+            try:
+                resp = self.network_client.network_interfaces.get(self.resource_group, nic['dep'].resource_name)
+            except ResourceNotFoundError:
+                pass
+            if resp is not None:
+                nic_list.append(resp)
+
         return [self.network_client.public_ip_addresses.get(public_ip_id.split('/')[4], public_ip_id.split('/')[-1])
-                for nic_obj in (self.network_client.network_interfaces.get(self.resource_group,
-                                                                           nic['dep'].resource_name) for nic in nics)
+                for nic_obj in nic_list
                 for public_ip_id in [ip_conf_instance.public_ip_address.id
                                      for ip_conf_instance in nic_obj.ip_configurations
                                      if ip_conf_instance.public_ip_address]]
