@@ -40,6 +40,7 @@ options:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
         type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -56,6 +57,8 @@ EXAMPLES = '''
       lab_name: myLab
       policy_set_name: myPolicySet
       name: myPolicy
+      tags:
+        - key:value
 '''
 
 RETURN = '''
@@ -119,9 +122,8 @@ policies:
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
 
 try:
-    from msrestazure.azure_exceptions import CloudError
+    from azure.core.exceptions import ResourceNotFoundError
     from azure.mgmt.devtestlabs import DevTestLabsClient
-    from msrest.serialization import Model
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -147,7 +149,8 @@ class AzureRMDtlPolicyInfo(AzureRMModuleBase):
                 type='str'
             ),
             tags=dict(
-                type='list'
+                type='list',
+                elements='str'
             )
         )
         # store the results of the module operation
@@ -160,7 +163,7 @@ class AzureRMDtlPolicyInfo(AzureRMModuleBase):
         self.policy_set_name = None
         self.name = None
         self.tags = None
-        super(AzureRMDtlPolicyInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False)
+        super(AzureRMDtlPolicyInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False, facts_module=True)
 
     def exec_module(self, **kwargs):
         is_old_facts = self.module._name == 'azure_rm_devtestlabpolicy_facts'
@@ -170,6 +173,7 @@ class AzureRMDtlPolicyInfo(AzureRMModuleBase):
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
         self.mgmt_client = self.get_mgmt_svc_client(DevTestLabsClient,
+                                                    is_track2=True,
                                                     base_url=self._cloud_environment.endpoints.resource_manager)
 
         if self.name:
@@ -188,7 +192,7 @@ class AzureRMDtlPolicyInfo(AzureRMModuleBase):
                                                      policy_set_name=self.policy_set_name,
                                                      name=self.name)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Could not get facts for Policy.')
 
         if response and self.has_tags(response.tags, self.tags):
@@ -204,7 +208,7 @@ class AzureRMDtlPolicyInfo(AzureRMModuleBase):
                                                       lab_name=self.lab_name,
                                                       policy_set_name=self.policy_set_name)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except Exception as e:
             self.log('Could not get facts for Policy.')
 
         if response is not None:
