@@ -69,6 +69,13 @@ options:
             - specialized
         required: true
         type: str
+    hypervgeneration:
+        description:
+            - This property allows you to specify the Hyper V Version of the Virtual Machines.
+        choices:
+            - V1
+            - V2
+        type: str
     end_of_life_date:
         description:
             - The end of life date of the gallery Image Definition.
@@ -198,10 +205,8 @@ id:
 
 import time
 import json
-import re
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_rest import GenericRestClient
-from copy import deepcopy
 try:
     from msrestazure.azure_exceptions import CloudError
 except ImportError:
@@ -267,6 +272,12 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
                 choices=['generalized',
                          'specialized']
             ),
+            hypervgeneration=dict(
+                type='str',
+                disposition='/properties/hyperVGeneration',
+                choices=['V1',
+                         'V2']
+            ),
             end_of_life_date=dict(
                 type='str',
                 disposition='/properties/endOfLifeDate'
@@ -386,6 +397,7 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
         response = None
 
         self.mgmt_client = self.get_mgmt_svc_client(GenericRestClient,
+                                                    is_track2=True,
                                                     base_url=self._cloud_environment.endpoints.resource_manager)
 
         resource_group = self.get_resource_group(self.resource_group)
@@ -484,9 +496,9 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
             self.fail('Error creating the GalleryImage instance: {0}'.format(str(exc)))
 
         try:
-            response = json.loads(response.text)
+            response = json.loads(response.body())
         except Exception:
-            response = {'text': response.text}
+            response = {'text': response.context['deserialized_data']}
 
         return response
 
@@ -519,7 +531,7 @@ class AzureRMGalleryImages(AzureRMModuleBaseExt):
                                               self.status_code,
                                               600,
                                               30)
-            response = json.loads(response.text)
+            response = json.loads(response.body())
             found = True
             self.log("Response : {0}".format(response))
             # self.log("AzureFirewall instance : {0} found".format(response.name))
