@@ -38,6 +38,7 @@ options:
             family:
                 description:
                     - SKU family name.
+                required: True
             name:
                 description:
                     - SKU name to specify whether the key vault is a standard vault or a premium vault.
@@ -133,6 +134,15 @@ options:
             - Property to specify whether the soft delete functionality is enabled for this key vault.
         type: bool
         default: True
+    enable_purge_protection:
+        description:
+            - Property specifying whether protection against purge is enabled for this vault.
+        type: bool
+        default: False
+    soft_delete_retention_in_days:
+        description:
+            - Property specifying the number of days to retain deleted vaults.
+        type: int
     recover_mode:
         description:
             - Create vault in recovery mode.
@@ -163,6 +173,7 @@ EXAMPLES = '''
       vault_tenant: 72f98888-8666-4144-9199-2d7cd0111111
       sku:
         name: standard
+        family: A
       access_policies:
         - tenant_id: 72f98888-8666-4144-9199-2d7cd0111111
           object_id: 99998888-8666-4144-9199-2d7cd0111111
@@ -180,15 +191,13 @@ id:
     sample: id
 '''
 
-import collections
 import time
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
 
 try:
-    from msrestazure.azure_exceptions import CloudError
+    from azure.core.polling import LROPoller
+    from azure.core.exceptions import ResourceNotFoundError
     from azure.mgmt.keyvault import KeyVaultManagementClient
-    from msrest.polling import LROPoller
-    from msrest.serialization import Model
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -247,6 +256,13 @@ class AzureRMVaults(AzureRMModuleBase):
                 type='bool',
                 default=True
             ),
+            soft_delete_retention_in_days=dict(
+                type='int'
+            ),
+            enable_purge_protection=dict(
+                type='bool',
+                default=False
+            ),
             recover_mode=dict(
                 type='bool'
             ),
@@ -315,6 +331,10 @@ class AzureRMVaults(AzureRMModuleBase):
                     self.parameters.setdefault("properties", {})["enabled_for_template_deployment"] = kwargs[key]
                 elif key == "enable_soft_delete":
                     self.parameters.setdefault("properties", {})["enable_soft_delete"] = kwargs[key]
+                elif key == "enable_purge_protection":
+                    self.parameters.setdefault("properties", {})["enable_purge_protection"] = kwargs[key]
+                elif key == "soft_delete_retention_in_days":
+                    self.parameters.setdefault("properties", {})["soft_delete_retention_in_days"] = kwargs[key]
                 elif key == "recover_mode":
                     self.parameters.setdefault("properties", {})["create_mode"] = 'recover' if kwargs[key] else 'default'
 
@@ -323,7 +343,8 @@ class AzureRMVaults(AzureRMModuleBase):
 
         self.mgmt_client = self.get_mgmt_svc_client(KeyVaultManagementClient,
                                                     base_url=self._cloud_environment.endpoints.resource_manager,
-                                                    api_version="2018-02-14")
+                                                    is_track2=True,
+                                                    api_version="2021-10-01")
 
         resource_group = self.get_resource_group(self.resource_group)
 
@@ -338,30 +359,42 @@ class AzureRMVaults(AzureRMModuleBase):
                 self.log("Old instance didn't exist")
             else:
                 self.to_do = Actions.Create
+                if not self.parameters['properties']['enable_purge_protection']:
+                    self.parameters['properties'].pop('enable_purge_protection')
         else:
             self.log("Key Vault instance already exists")
             if self.state == 'absent':
                 self.to_do = Actions.Delete
             elif self.state == 'present':
                 self.log("Need to check if Key Vault instance has to be deleted or may be updated")
+                if not self.parameters['properties']['enable_purge_protection'] and \
+                        ('enable_purge_protection' not in old_response['properties'] or
+                         not old_response['properties']['enable_purge_protection']):
+                    self.parameters['properties'].pop('enable_purge_protection')
                 if ('location' in self.parameters) and (self.parameters['location'] != old_response['location']):
                     self.to_do = Actions.Update
                 elif (('tenant_id' in self.parameters['properties']) and
                         (self.parameters['properties']['tenant_id'] != old_response['properties']['tenant_id'])):
                     self.to_do = Actions.Update
                 elif (('enabled_for_deployment' in self.parameters['properties']) and
-                        (self.parameters['properties']['enabled_for_deployment'] != getattr(old_response['properties'], 'enabled_for_deployment', None))):
+                        (self.parameters['properties']['enabled_for_deployment'] != old_response['properties'].get('enabled_for_deployment', None))):
                     self.to_do = Actions.Update
                 elif (('enabled_for_disk_encryption' in self.parameters['properties']) and
                         (self.parameters['properties']['enabled_for_disk_encryption'] !=
-                         getattr(old_response['properties'], 'enabled_for_disk_encryption', None))):
+                         old_response['properties'].get('enabled_for_disk_encryption', None))):
                     self.to_do = Actions.Update
                 elif (('enabled_for_template_deployment' in self.parameters['properties']) and
                         (self.parameters['properties']['enabled_for_template_deployment'] !=
-                         getattr(old_response['properties'], 'enabled_for_template_deployment', None))):
+                         old_response['properties'].get('enabled_for_template_deployment', None))):
                     self.to_do = Actions.Update
                 elif (('enable_soft_delete' in self.parameters['properties']) and
-                        (self.parameters['properties']['enable_soft_delete'] != getattr(old_response['properties'], 'enable_soft_delete', None))):
+                        (self.parameters['properties']['enable_soft_delete'] != old_response['properties'].get('enable_soft_delete', None))):
+                    self.to_do = Actions.Update
+                elif (('soft_delete_retention_in_days' in self.parameters['properties']) and
+                        (self.parameters['properties']['soft_delete_retention_in_days'] != old_response['properties'].get('soft_delete_retention_in_days'))):
+                    self.to_do = Actions.Update
+                elif (('enable_purge_protection' in self.parameters['properties']) and
+                      (self.parameters['properties']['enable_purge_protection'] != old_response['properties'].get('enable_purge_protection'))):
                     self.to_do = Actions.Update
                 elif ('create_mode' in self.parameters['properties']) and (self.parameters['properties']['create_mode'] == 'recover'):
                     self.to_do = Actions.Update
@@ -448,13 +481,13 @@ class AzureRMVaults(AzureRMModuleBase):
         self.log("Creating / Updating the Key Vault instance {0}".format(self.vault_name))
 
         try:
-            response = self.mgmt_client.vaults.create_or_update(resource_group_name=self.resource_group,
-                                                                vault_name=self.vault_name,
-                                                                parameters=self.parameters)
+            response = self.mgmt_client.vaults.begin_create_or_update(resource_group_name=self.resource_group,
+                                                                      vault_name=self.vault_name,
+                                                                      parameters=self.parameters)
             if isinstance(response, LROPoller):
                 response = self.get_poller_result(response)
 
-        except CloudError as exc:
+        except Exception as exc:
             self.log('Error attempting to create the Key Vault instance.')
             self.fail("Error creating the Key Vault instance: {0}".format(str(exc)))
         return response.as_dict()
@@ -469,7 +502,7 @@ class AzureRMVaults(AzureRMModuleBase):
         try:
             response = self.mgmt_client.vaults.delete(resource_group_name=self.resource_group,
                                                       vault_name=self.vault_name)
-        except CloudError as e:
+        except Exception as e:
             self.log('Error attempting to delete the Key Vault instance.')
             self.fail("Error deleting the Key Vault instance: {0}".format(str(e)))
 
@@ -489,7 +522,7 @@ class AzureRMVaults(AzureRMModuleBase):
             found = True
             self.log("Response : {0}".format(response))
             self.log("Key Vault instance : {0} found".format(response.name))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Did not find the Key Vault instance.')
         if found is True:
             return response.as_dict()
