@@ -403,12 +403,9 @@ changed:
     type: bool
 '''
 
-import random
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase, format_resource_id
 from ansible.module_utils._text import to_native
 try:
-    from msrestazure.tools import parse_resource_id
-    from msrestazure.azure_exceptions import CloudError
     from azure.core.exceptions import ResourceNotFoundError
 except ImportError:
     # This is handled in azure_rm_common
@@ -813,7 +810,7 @@ class AzureRMLoadBalancer(AzureRMModuleBase):
                     ) if new_front[index].get('public_ip_address') else None,
                     private_ip_address=new_front[index].get('private_ip_address'),
                     private_ip_allocation_method=new_front[index].get('private_ip_allocation_method'),
-                    zones=new_front[index].get('zones') if new_front[index].get('zones') else old_front[index].zones,
+                    zones=new_front[index].get('zones') if new_front[index].get('zones') else None,
                     subnet=self.network_models.Subnet(
                         id=new_front[index].get('subnet'),
                         private_endpoint_network_policies=None,
