@@ -77,10 +77,8 @@ import time
 
 try:
     from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
-    from msrestazure.azure_exceptions import CloudError
-    from msrest.polling import LROPoller
-    from azure.mgmt.rdbms.mysql import MySQLManagementClient
-    from msrest.serialization import Model
+    from azure.core.exceptions import ResourceNotFoundError
+    from azure.core.polling import LROPoller
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -128,6 +126,7 @@ class AzureRMMySqlFirewallRule(AzureRMModuleBase):
 
         self.results = dict(changed=False)
         self.state = None
+        self.parameters = dict()
         self.to_do = Actions.NoAction
 
         super(AzureRMMySqlFirewallRule, self).__init__(derived_arg_spec=self.module_arg_spec,
@@ -140,6 +139,8 @@ class AzureRMMySqlFirewallRule(AzureRMModuleBase):
         for key in list(self.module_arg_spec.keys()):
             if hasattr(self, key):
                 setattr(self, key, kwargs[key])
+                if key in ['start_ip_address', 'end_ip_address']:
+                    self.parameters[key] = kwargs[key]
 
         old_response = None
         response = None
@@ -210,15 +211,14 @@ class AzureRMMySqlFirewallRule(AzureRMModuleBase):
         self.log("Creating / Updating the MySQL firewall rule instance {0}".format(self.name))
 
         try:
-            response = self.mysql_client.firewall_rules.create_or_update(resource_group_name=self.resource_group,
-                                                                         server_name=self.server_name,
-                                                                         firewall_rule_name=self.name,
-                                                                         start_ip_address=self.start_ip_address,
-                                                                         end_ip_address=self.end_ip_address)
+            response = self.mysql_client.firewall_rules.begin_create_or_update(resource_group_name=self.resource_group,
+                                                                               server_name=self.server_name,
+                                                                               firewall_rule_name=self.name,
+                                                                               parameters=self.parameters)
             if isinstance(response, LROPoller):
                 response = self.get_poller_result(response)
 
-        except CloudError as exc:
+        except Exception as exc:
             self.log('Error attempting to create the MySQL firewall rule instance.')
             self.fail("Error creating the MySQL firewall rule instance: {0}".format(str(exc)))
         return response.as_dict()
@@ -231,10 +231,10 @@ class AzureRMMySqlFirewallRule(AzureRMModuleBase):
         '''
         self.log("Deleting the MySQL firewall rule instance {0}".format(self.name))
         try:
-            response = self.mysql_client.firewall_rules.delete(resource_group_name=self.resource_group,
-                                                               server_name=self.server_name,
-                                                               firewall_rule_name=self.name)
-        except CloudError as e:
+            response = self.mysql_client.firewall_rules.begin_delete(resource_group_name=self.resource_group,
+                                                                     server_name=self.server_name,
+                                                                     firewall_rule_name=self.name)
+        except Exception as e:
             self.log('Error attempting to delete the MySQL firewall rule instance.')
             self.fail("Error deleting the MySQL firewall rule instance: {0}".format(str(e)))
 
@@ -255,7 +255,7 @@ class AzureRMMySqlFirewallRule(AzureRMModuleBase):
             found = True
             self.log("Response : {0}".format(response))
             self.log("MySQL firewall rule instance : {0} found".format(response.name))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Did not find the MySQL firewall rule instance.')
         if found is True:
             return response.as_dict()
