@@ -26,10 +26,14 @@ options:
         description:
             - The name of the server.
         type: str
+    tags:
+        description:
+            - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
+        type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
-    - azure.azcollection.azure_tags
 
 author:
     - Zim Kalinowski (@zikalino)
@@ -41,6 +45,8 @@ EXAMPLES = '''
     azure_rm_mysqlserver_info:
       resource_group: myResourceGroup
       name: server_name
+      tags:
+        - key
 
   - name: List instances of MySQL Server
     azure_rm_mysqlserver_info:
@@ -171,9 +177,7 @@ servers:
 
 try:
     from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
-    from msrestazure.azure_exceptions import CloudError
-    from azure.mgmt.rdbms.mysql import MySQLManagementClient
-    from msrest.serialization import Model
+    from azure.core.exceptions import ResourceNotFoundError
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -189,6 +193,10 @@ class AzureRMMySqlServerInfo(AzureRMModuleBase):
             ),
             name=dict(
                 type='str'
+            ),
+            tags=dict(
+                type='list',
+                elements='str'
             )
         )
         # store the results of the module operation
@@ -198,7 +206,7 @@ class AzureRMMySqlServerInfo(AzureRMModuleBase):
         self.resource_group = None
         self.name = None
         self.tags = None
-        super(AzureRMMySqlServerInfo, self).__init__(self.module_arg_spec, supports_tags=True)
+        super(AzureRMMySqlServerInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False, facts_module=True)
 
     def exec_module(self, **kwargs):
         is_old_facts = self.module._name == 'azure_rm_mysqlserver_facts'
@@ -222,7 +230,7 @@ class AzureRMMySqlServerInfo(AzureRMModuleBase):
             response = self.mysql_client.servers.get(resource_group_name=self.resource_group,
                                                      server_name=self.name)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Could not get facts for MySQL Server.')
 
         if response and self.has_tags(response.tags, self.tags):
@@ -236,7 +244,7 @@ class AzureRMMySqlServerInfo(AzureRMModuleBase):
         try:
             response = self.mysql_client.servers.list_by_resource_group(resource_group_name=self.resource_group)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except Exception as e:
             self.log('Could not get facts for MySQL Servers.')
 
         if response is not None:
