@@ -41,7 +41,6 @@ options:
                 description:
                     - Pull secret for the cluster (immutable).
                 type: str
-                default: ""
             domain:
                 description:
                     - The domain for the cluster (immutable).
@@ -93,9 +92,9 @@ options:
                     - Size of agent VMs (immutable).
                 type: str
                 choices:
-                    - Standard_D2s_v3
-                    - Standard_D4s_v3
                     - Standard_D8s_v3
+                    - Standard_D16s_v3
+                    - Standard_D32s_v3
             subnet_id:
                 description:
                     - The Azure resource ID of the master subnet (immutable).
@@ -117,7 +116,6 @@ options:
                     - The size of the worker Vms (immutable).
                 type: str
                 choices:
-                    - Standard_D2s_v3
                     - Standard_D4s_v3
                     - Standard_D8s_v3
             disk_size:
@@ -440,6 +438,7 @@ class AzureRMOpenShiftManagedClusters(AzureRMModuleBaseExt):
                 options=dict(
                     pull_secret=dict(
                         type='str',
+                        no_log=True,
                         updatable=False,
                         disposition='pullSecret',
                         purgeIfNone=True
@@ -476,6 +475,7 @@ class AzureRMOpenShiftManagedClusters(AzureRMModuleBaseExt):
                     ),
                     client_secret=dict(
                         type='str',
+                        no_log=True,
                         updatable=False,
                         disposition='clientSecret',
                         required=True
@@ -510,9 +510,9 @@ class AzureRMOpenShiftManagedClusters(AzureRMModuleBaseExt):
                         type='str',
                         updatable=False,
                         disposition='vmSize',
-                        choices=['Standard_D2s_v3',
-                                 'Standard_D4s_v3',
-                                 'Standard_D8s_v3'],
+                        choices=['Standard_D8s_v3',
+                                 'Standard_D16s_v3',
+                                 'Standard_D32s_v3'],
                         purgeIfNone=True
                     ),
                     subnet_id=dict(
@@ -544,8 +544,7 @@ class AzureRMOpenShiftManagedClusters(AzureRMModuleBaseExt):
                         type='str',
                         disposition='vmSize',
                         updatable=False,
-                        choices=['Standard_D2s_v3',
-                                 'Standard_D4s_v3',
+                        choices=['Standard_D4s_v3',
                                  'Standard_D8s_v3'],
                         purgeIfNone=True
                     ),
@@ -653,6 +652,7 @@ class AzureRMOpenShiftManagedClusters(AzureRMModuleBaseExt):
         response = None
 
         self.mgmt_client = self.get_mgmt_svc_client(GenericRestClient,
+                                                    is_track2=True,
                                                     base_url=self._cloud_environment.endpoints.resource_manager)
 
         self.url = ('/subscriptions' +
@@ -755,12 +755,12 @@ class AzureRMOpenShiftManagedClusters(AzureRMModuleBaseExt):
                                               30)
         except CloudError as exc:
             self.log('Error attempting to create the OpenShiftManagedCluster instance.')
-            self.fail('Error creating the OpenShiftManagedCluster instance: {0}'.format(str(self.body)))
-            self.fail('Error creating the OpenShiftManagedCluster instance: {0}'.format(str(exc)))
+            self.fail('Error creating the OpenShiftManagedCluster instance: {0}'
+                      '\n{1}'.format(str(self.body), str(exc)))
         try:
-            response = json.loads(response.text)
+            response = json.loads(response.body())
         except Exception:
-            response = {'text': response.text}
+            response = {'text': response.context['deserialized_data']}
             pass
 
         return response
@@ -778,7 +778,7 @@ class AzureRMOpenShiftManagedClusters(AzureRMModuleBaseExt):
                                               30)
         except CloudError as e:
             self.log('Error attempting to delete the OpenShiftManagedCluster instance.')
-            # self.fail('Error deleting the OpenShiftManagedCluster instance: {0}'.format(str(e)))
+            self.fail('Error deleting the OpenShiftManagedCluster instance: {0}'.format(str(e)))
 
         return True
 
@@ -795,7 +795,7 @@ class AzureRMOpenShiftManagedClusters(AzureRMModuleBaseExt):
                                               600,
                                               30)
             found = True
-            response = json.loads(response.text)
+            response = json.loads(response.body())
             found = True
             self.log("Response : {0}".format(response))
             # self.log("OpenShiftManagedCluster instance : {0} found".format(response.name))
