@@ -87,10 +87,8 @@ import time
 
 try:
     from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
-    from azure.mgmt.rdbms.postgresql import PostgreSQLManagementClient
-    from msrestazure.azure_exceptions import CloudError
-    from msrest.polling import LROPoller
-    from msrest.serialization import Model
+    from azure.core.exceptions import ResourceNotFoundError
+    from azure.core.polling import LROPoller
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -141,7 +139,6 @@ class AzureRMPostgreSqlDatabases(AzureRMModuleBase):
         self.parameters = dict()
 
         self.results = dict(changed=False)
-        self.mgmt_client = None
         self.state = None
         self.to_do = Actions.NoAction
 
@@ -164,9 +161,6 @@ class AzureRMPostgreSqlDatabases(AzureRMModuleBase):
         old_response = None
         response = None
 
-        self.mgmt_client = self.get_mgmt_svc_client(PostgreSQLManagementClient,
-                                                    base_url=self._cloud_environment.endpoints.resource_manager)
-
         resource_group = self.get_resource_group(self.resource_group)
 
         old_response = self.get_postgresqldatabase()
@@ -237,14 +231,14 @@ class AzureRMPostgreSqlDatabases(AzureRMModuleBase):
         self.log("Creating / Updating the PostgreSQL Database instance {0}".format(self.name))
 
         try:
-            response = self.mgmt_client.databases.create_or_update(resource_group_name=self.resource_group,
-                                                                   server_name=self.server_name,
-                                                                   database_name=self.name,
-                                                                   parameters=self.parameters)
+            response = self.postgresql_client.databases.begin_create_or_update(resource_group_name=self.resource_group,
+                                                                               server_name=self.server_name,
+                                                                               database_name=self.name,
+                                                                               parameters=self.parameters)
             if isinstance(response, LROPoller):
                 response = self.get_poller_result(response)
 
-        except CloudError as exc:
+        except Exception as exc:
             self.log('Error attempting to create the PostgreSQL Database instance.')
             self.fail("Error creating the PostgreSQL Database instance: {0}".format(str(exc)))
         return response.as_dict()
@@ -257,10 +251,10 @@ class AzureRMPostgreSqlDatabases(AzureRMModuleBase):
         '''
         self.log("Deleting the PostgreSQL Database instance {0}".format(self.name))
         try:
-            response = self.mgmt_client.databases.delete(resource_group_name=self.resource_group,
-                                                         server_name=self.server_name,
-                                                         database_name=self.name)
-        except CloudError as e:
+            response = self.postgresql_client.databases.begin_delete(resource_group_name=self.resource_group,
+                                                                     server_name=self.server_name,
+                                                                     database_name=self.name)
+        except Exception as e:
             self.log('Error attempting to delete the PostgreSQL Database instance.')
             self.fail("Error deleting the PostgreSQL Database instance: {0}".format(str(e)))
 
@@ -275,13 +269,13 @@ class AzureRMPostgreSqlDatabases(AzureRMModuleBase):
         self.log("Checking if the PostgreSQL Database instance {0} is present".format(self.name))
         found = False
         try:
-            response = self.mgmt_client.databases.get(resource_group_name=self.resource_group,
-                                                      server_name=self.server_name,
-                                                      database_name=self.name)
+            response = self.postgresql_client.databases.get(resource_group_name=self.resource_group,
+                                                            server_name=self.server_name,
+                                                            database_name=self.name)
             found = True
             self.log("Response : {0}".format(response))
             self.log("PostgreSQL Database instance : {0} found".format(response.name))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Did not find the PostgreSQL Database instance.')
         if found is True:
             return response.as_dict()
