@@ -21,13 +21,16 @@ options:
         description:
             - The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
         required: True
+        type: str
     name:
         description:
             - The name of the server.
         required: True
+        type: str
     sku:
         description:
             - The SKU (pricing tier) of the server.
+        type: dict
         suboptions:
             name:
                 description:
@@ -47,13 +50,24 @@ options:
     location:
         description:
             - Resource location. If not set, location from the resource group will be used as default.
+        type: str
     storage_mb:
         description:
             - The maximum storage allowed for a server.
         type: int
+    geo_redundant_backup:
+        description:
+            - Choose between locally redundant(default) or geo-redundant backup. This cannot be updated after first deployment
+        type: bool
+        default: False
+    backup_retention_days:
+        description:
+            - Backup retention period between 7 and 35 days. 7 days by default if not set
+        type: int
     version:
         description:
             - Server version.
+        type: str
         choices:
             - '9.5'
             - '9.6'
@@ -72,17 +86,34 @@ options:
     admin_username:
         description:
             - The administrator's login name of a server. Can only be specified when the server is being created (and is required for creation).
+        type: str
     admin_password:
         description:
             - The password of the administrator login.
+        type: str
     create_mode:
         description:
-            - Create mode of SQL Server.
-        default: Default
+            - Create mode of SQL Server. Blank (default), restore from geo redundant (geo_restore), or restore from point in time (point_in_time_restore).
+        type: str
+        default: default
+        choices:
+            - default
+            - geo_restore
+            - point_in_time_restore
+    source_server_id:
+        description:
+            - Id if the source server if I(create_mode=default).
+        type: str
+    restore_point_in_time:
+        description:
+            - Restore point creation time (ISO8601 format), specifying the time to restore from.
+            - Required if I(create_mode=point_in_time_restore).
+        type: str
     state:
         description:
             - Assert the state of the PostgreSQL server. Use C(present) to create or update a server and C(absent) to delete it.
         default: present
+        type: str
         choices:
             - present
             - absent
@@ -143,10 +174,8 @@ import time
 
 try:
     from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
-    from azure.mgmt.rdbms.postgresql import PostgreSQLManagementClient
-    from msrestazure.azure_exceptions import CloudError
-    from msrest.polling import LROPoller
-    from msrest.serialization import Model
+    from azure.core.exceptions import ResourceNotFoundError
+    from azure.core.polling import LROPoller
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -178,6 +207,13 @@ class AzureRMPostgreSqlServers(AzureRMModuleBase):
             storage_mb=dict(
                 type='int'
             ),
+            geo_redundant_backup=dict(
+                type='bool',
+                default=False
+            ),
+            backup_retention_days=dict(
+                type='int',
+            ),
             version=dict(
                 type='str',
                 choices=['9.5', '9.6', '10', '11']
@@ -192,7 +228,14 @@ class AzureRMPostgreSqlServers(AzureRMModuleBase):
             ),
             create_mode=dict(
                 type='str',
-                default='Default'
+                default='default',
+                choices=['default', 'geo_restore', 'point_in_time_restore']
+            ),
+            source_server_id=dict(
+                type='str'
+            ),
+            restore_point_in_time=dict(
+                type='str'
             ),
             admin_username=dict(
                 type='str'
@@ -210,7 +253,7 @@ class AzureRMPostgreSqlServers(AzureRMModuleBase):
 
         self.resource_group = None
         self.name = None
-        self.parameters = dict()
+        self.parameters = {'properties': {'create_mode': 'default'}}
         self.tags = None
 
         self.results = dict(changed=False)
@@ -239,20 +282,39 @@ class AzureRMPostgreSqlServers(AzureRMModuleBase):
                 elif key == "location":
                     self.parameters["location"] = kwargs[key]
                 elif key == "storage_mb":
-                    self.parameters.setdefault("properties", {}).setdefault("storage_profile", {})["storage_mb"] = kwargs[key]
+                    self.parameters.setdefault("properties", {}).setdefault("storage_profile", {})["storage_mb"] = \
+                        kwargs[key]
                 elif key == "storage_autogrow":
-                    self.parameters.setdefault("properties", {}).setdefault("storage_profile", {})["storage_autogrow"] = ('Enabled' if kwargs[key]
-                                                                                                                          else 'Disabled')
+                    self.parameters.setdefault("properties", {}).setdefault("storage_profile", {})[
+                        "storage_autogrow"] = ('Enabled' if kwargs[key]
+                                               else 'Disabled')
+                elif key == "geo_redundant_backup":
+                    self.parameters.setdefault("properties", {}).setdefault("storage_profile", {})[
+                        "geo_redundant_backup"] = \
+                        'Enabled' if kwargs[key] else 'Disabled'
+                elif key == "backup_retention_days":
+                    self.parameters.setdefault("properties", {}).setdefault("storage_profile", {})[
+                        "backup_retention_days"] = kwargs[key]
                 elif key == "version":
                     self.parameters.setdefault("properties", {})["version"] = kwargs[key]
                 elif key == "enforce_ssl":
-                    self.parameters.setdefault("properties", {})["ssl_enforcement"] = 'Enabled' if kwargs[key] else 'Disabled'
+                    self.parameters.setdefault("properties", {})["ssl_enforcement"] = 'Enabled' if kwargs[
+                        key] else 'Disabled'
                 elif key == "create_mode":
-                    self.parameters.setdefault("properties", {})["create_mode"] = kwargs[key]
+                    if kwargs[key] == 'default':
+                        self.parameters["properties"]["create_mode"] = 'Default'
+                    elif kwargs[key] == 'point_in_time_restore':
+                        self.parameters["properties"]["create_mode"] = 'PointInTimeRestore'
+                    elif kwargs[key] == 'geo_restore':
+                        self.parameters["properties"]["create_mode"] = 'GeoRestore'
                 elif key == "admin_username":
                     self.parameters.setdefault("properties", {})["administrator_login"] = kwargs[key]
                 elif key == "admin_password":
                     self.parameters.setdefault("properties", {})["administrator_login_password"] = kwargs[key]
+                elif key == "source_server_id":
+                    self.parameters["properties"]["source_server_id"] = kwargs[key]
+                elif key == "restore_point_in_time":
+                    self.parameters["properties"]["restore_point_in_time"] = kwargs[key]
 
         old_response = None
         response = None
@@ -331,19 +393,19 @@ class AzureRMPostgreSqlServers(AzureRMModuleBase):
         try:
             self.parameters['tags'] = self.tags
             if self.to_do == Actions.Create:
-                response = self.postgresql_client.servers.create(resource_group_name=self.resource_group,
-                                                                 server_name=self.name,
-                                                                 parameters=self.parameters)
+                response = self.postgresql_client.servers.begin_create(resource_group_name=self.resource_group,
+                                                                       server_name=self.name,
+                                                                       parameters=self.parameters)
             else:
                 # structure of parameters for update must be changed
                 self.parameters.update(self.parameters.pop("properties", {}))
-                response = self.postgresql_client.servers.update(resource_group_name=self.resource_group,
-                                                                 server_name=self.name,
-                                                                 parameters=self.parameters)
+                response = self.postgresql_client.servers.begin_update(resource_group_name=self.resource_group,
+                                                                       server_name=self.name,
+                                                                       parameters=self.parameters)
             if isinstance(response, LROPoller):
                 response = self.get_poller_result(response)
 
-        except CloudError as exc:
+        except Exception as exc:
             self.log('Error attempting to create the PostgreSQL Server instance.')
             self.fail("Error creating the PostgreSQL Server instance: {0}".format(str(exc)))
         return response.as_dict()
@@ -356,9 +418,9 @@ class AzureRMPostgreSqlServers(AzureRMModuleBase):
         '''
         self.log("Deleting the PostgreSQL Server instance {0}".format(self.name))
         try:
-            response = self.postgresql_client.servers.delete(resource_group_name=self.resource_group,
-                                                             server_name=self.name)
-        except CloudError as e:
+            response = self.postgresql_client.servers.begin_delete(resource_group_name=self.resource_group,
+                                                                   server_name=self.name)
+        except Exception as e:
             self.log('Error attempting to delete the PostgreSQL Server instance.')
             self.fail("Error deleting the PostgreSQL Server instance: {0}".format(str(e)))
 
@@ -378,7 +440,7 @@ class AzureRMPostgreSqlServers(AzureRMModuleBase):
             found = True
             self.log("Response : {0}".format(response))
             self.log("PostgreSQL Server instance : {0} found".format(response.name))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Did not find the PostgreSQL Server instance.')
         if found is True:
             return response.as_dict()
