@@ -120,12 +120,8 @@ roledefinitions:
                     sample: [ 'Microsoft.Storage/storageAccounts/blobServices/containers/blobs/write' ]
 '''
 
-from ansible.module_utils._text import to_native
-
 try:
     from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
-    from msrestazure.azure_exceptions import CloudError
-    from msrest.serialization import Model
     from azure.mgmt.authorization import AuthorizationManagementClient
 
 except ImportError:
@@ -179,6 +175,7 @@ class AzureRMRoleDefinitionInfo(AzureRMModuleBase):
         self._client = None
 
         super(AzureRMRoleDefinitionInfo, self).__init__(derived_arg_spec=self.module_arg_spec,
+                                                        supports_check_mode=True,
                                                         supports_tags=False)
 
     def exec_module(self, **kwargs):
@@ -197,6 +194,7 @@ class AzureRMRoleDefinitionInfo(AzureRMModuleBase):
         # get management client
         self._client = self.get_mgmt_svc_client(AuthorizationManagementClient,
                                                 base_url=self._cloud_environment.endpoints.resource_manager,
+                                                is_track2=True,
                                                 api_version="2018-01-01-preview")
 
         if self.id:
@@ -241,7 +239,7 @@ class AzureRMRoleDefinitionInfo(AzureRMModuleBase):
                 if len(roles) > 0:
                     return [roledefinition_to_dict(r) for r in roles]
 
-        except CloudError as ex:
+        except Exception as ex:
             self.log("Didn't find role definition in scope {0}".format(self.scope))
 
         return response
@@ -266,7 +264,7 @@ class AzureRMRoleDefinitionInfo(AzureRMModuleBase):
                 else:
                     return [response]
 
-        except CloudError as ex:
+        except Exception as ex:
             self.log("Didn't find role definition by id {0}".format(self.id))
 
         return []
@@ -296,7 +294,7 @@ class AzureRMRoleDefinitionInfo(AzureRMModuleBase):
                 if len(roles) > 1:
                     self.fail("Found multiple Role Definitions with name: {0}".format(self.role_name))
 
-        except CloudError as ex:
+        except Exception as ex:
             self.log("Didn't find Role Definition by name {0}".format(self.role_name))
 
         return []
