@@ -102,6 +102,7 @@ options:
                     - It could be list of dict containing resource_group and name.
                     - It is mutually exclusive with C(source_address_prefix) and C(source_address_prefixes).
                 type: list
+                elements: raw
             destination_application_security_groups:
                 description:
                     - List of the destination application security groups.
@@ -110,6 +111,7 @@ options:
                     - It could be list of dict containing I(resource_group) and I(name).
                     - It is mutually exclusive with C(destination_address_prefix) and C(destination_address_prefixes).
                 type: list
+                elements: raw
             access:
                 description:
                     - Whether or not to allow the traffic flow.
@@ -416,13 +418,11 @@ state:
 try:
     from azure.core.exceptions import ResourceNotFoundError
     from msrestazure.tools import is_valid_resource_id
-    from azure.mgmt.network import NetworkManagementClient
 except ImportError:
     # This is handled in azure_rm_common
     pass
 
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
-from ansible.module_utils.six import integer_types
 from ansible.module_utils._text import to_native
 
 
@@ -461,7 +461,7 @@ def compare_rules_change(old_list, new_list, purge_list):
     changed = False
 
     for old_rule in old_list:
-        matched = next((x for x in new_list if x['name'] == old_rule['name']), [])
+        matched = next((x for x in new_list if x['name'].lower() == old_rule['name'].lower()), [])
         if matched:  # if the new one is in the old list, check whether it is updated
             changed = changed or compare_rules(old_rule, matched)
         elif not purge_list:  # keep this rule
@@ -470,8 +470,8 @@ def compare_rules_change(old_list, new_list, purge_list):
             changed = True
     # Compare new list and old list is the same? here only compare names
     if not changed:
-        new_names = [to_native(x['name']) for x in new_list]
-        old_names = [to_native(x['name']) for x in old_list]
+        new_names = [to_native(x['name'].lower()) for x in new_list]
+        old_names = [to_native(x['name'].lower()) for x in old_list]
         changed = (set(new_names) != set(old_names))
     return changed, new_list
 
@@ -480,11 +480,11 @@ def compare_rules(old_rule, rule):
     def compare_list_rule(old_rule, rule, key):
         return set(map(str, rule.get(key) or [])) != set(map(str, old_rule.get(key) or []))
     changed = False
-    if old_rule['name'] != rule['name']:
+    if old_rule['name'].lower() != rule['name'].lower():
         changed = True
     if rule.get('description', None) != old_rule['description']:
         changed = True
-    if rule['protocol'] != old_rule['protocol']:
+    if rule['protocol'].lower() != old_rule['protocol'].lower():
         changed = True
     if str(rule['source_port_range']) != str(old_rule['source_port_range']):
         changed = True
