@@ -533,11 +533,6 @@ storageaccounts:
                     sample: error.html
 '''
 
-try:
-    from azure.core.exceptions import ResourceNotFoundError
-except Exception:
-    # This is handled in azure_rm_common
-    pass
 
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
 from ansible.module_utils._text import to_native
@@ -609,7 +604,7 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
         account = None
         try:
             expand = None
-            if(self.show_georeplication_stats):
+            if (self.show_georeplication_stats):
                 expand = 'georeplicationstats'
             account = self.storage_client.storage_accounts.get_properties(self.resource_group, self.name, expand=expand)
             return [account]
