@@ -145,14 +145,11 @@ from ansible.module_utils.common.dict_transformations import (
 )
 
 try:
-    from msrestazure.azure_exceptions import CloudError
-    from azure.common import AzureHttpError
+    from azure.core.exceptions import ResourceNotFoundError
 except Exception:
     # handled in azure_rm_common
     pass
 
-import re
-
 AZURE_OBJECT_CLASS = 'TrafficManagerEndpoints'
 
 
@@ -215,6 +212,7 @@ class AzureRMTrafficManagerEndpointInfo(AzureRMModuleBase):
 
         super(AzureRMTrafficManagerEndpointInfo, self).__init__(
             derived_arg_spec=self.module_args,
+            supports_check_mode=True,
             supports_tags=False,
             facts_module=True
         )
@@ -254,7 +252,7 @@ class AzureRMTrafficManagerEndpointInfo(AzureRMModuleBase):
         try:
             item = self.traffic_manager_management_client.endpoints.get(
                 self.resource_group, self.profile_name, self.type, self.name)
-        except CloudError:
+        except ResourceNotFoundError:
             pass
 
         if item:
@@ -270,7 +268,7 @@ class AzureRMTrafficManagerEndpointInfo(AzureRMModuleBase):
 
         try:
             response = self.traffic_manager_management_client.profiles.get(self.resource_group, self.profile_name)
-        except AzureHttpError as exc:
+        except Exception as exc:
             self.fail('Failed to list all items - {0}'.format(str(exc)))
 
         results = []
@@ -285,7 +283,7 @@ class AzureRMTrafficManagerEndpointInfo(AzureRMModuleBase):
         self.log('List all Traffic Manager endpoints of a profile by type')
         try:
             response = self.traffic_manager_management_client.profiles.get(self.resource_group, self.profile_name)
-        except AzureHttpError as exc:
+        except Exception as exc:
             self.fail('Failed to list all items - {0}'.format(str(exc)))
 
         results = []
