@@ -31,6 +31,8 @@ options:
     tags:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
+        type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -269,6 +271,44 @@ vms:
             returned: always
             type: str
             sample: running
+        security_profile:
+            description:
+                - Specifies the Security related profile settings for the virtual machine.
+            type: complex
+            returned: when-used
+            contains:
+                encryption_at_host:
+                    description:
+                        - This property can be used by user in the request to enable or disable the Host Encryption for the virtual machine.
+                        - This will enable the encryption for all the disks including Resource/Temp disk at host itself.
+                    type: bool
+                    returned: when-enabled
+                    sample: True
+                security_type:
+                    description:
+                        - Specifies the SecurityType of the virtual machine.
+                        - It is set as TrustedLaunch to enable UefiSettings.
+                    type: str
+                    returned: when-enabled
+                    sample: TrustedLaunch
+                uefi_settings:
+                    description:
+                        - Specifies the security settings like secure boot and vTPM used while creating the virtual machine.
+                    type: complex
+                    returned: when-enabled
+                    contains:
+                        secure_boot_enabled:
+                            description:
+                                - Specifies whether secure boot should be enabled on the virtual machine.
+                            type: bool
+                            returned: when-enabled
+                            sample: True
+                        v_tpm_enabled:
+                            description:
+                                - Specifies whether vTPM should be enabled on the virtual machine.
+                            type: bool
+                            returned: when-enabled
+                            sample: True
 '''
 
 try:
@@ -295,7 +335,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         self.module_arg_spec = dict(
             resource_group=dict(type='str'),
             name=dict(type='str'),
-            tags=dict(type='list')
+            tags=dict(type='list', elements='str')
         )
 
         self.results = dict(
@@ -393,6 +433,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         resource_group = parse_resource_id(result['id']).get('resource_group')
         instance = None
         power_state = None
+        display_status = None
 
         try:
             instance = self.compute_client.virtual_machines.instance_view(resource_group, vm.name)
@@ -404,17 +445,31 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
             code = instance['statuses'][index]['code'].split('/')
             if code[0] == 'PowerState':
                 power_state = code[1]
-                display_status = instance['statuses'][index]['displayStatus']
+                display_status = instance['statuses'][index]['display_status']
             elif code[0] == 'OSState' and code[1] == 'generalized':
-                display_status = instance['statuses'][index]['displayStatus']
+                display_status = instance['statuses'][index]['display_status']
                 power_state = 'generalized'
                 break
             elif code[0] == 'ProvisioningState' and code[1] == 'failed':
-                display_status = instance['statuses'][index]['displayStatus']
+                display_status = instance['statuses'][index]['display_status']
                 power_state = ''
                 break
 
         new_result = {}
+
+        if vm.security_profile is not None:
+            new_result['security_profile'] = dict()
+            if vm.security_profile.encryption_at_host is not None:
+                new_result['security_profile']['encryption_at_host'] = vm.security_profile.encryption_at_host
+            if vm.security_profile.security_type is not None:
+                new_result['security_profile']['security_type'] = vm.security_profile.security_type
+            if vm.security_profile.uefi_settings is not None:
+                new_result['security_profile']['uefi_settings'] = dict()
+                if vm.security_profile.uefi_settings.secure_boot_enabled is not None:
+                    new_result['security_profile']['uefi_settings']['secure_boot_enabled'] = vm.security_profile.uefi_settings.secure_boot_enabled
+                if vm.security_profile.uefi_settings.v_tpm_enabled is not None:
+                    new_result['security_profile']['uefi_settings']['v_tpm_enabled'] = vm.security_profile.uefi_settings.v_tpm_enabled
+
         new_result['power_state'] = power_state
         new_result['display_status'] = display_status
         new_result['provisioning_state'] = vm.provisioning_state
@@ -423,13 +478,13 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         new_result['name'] = vm.name
         new_result['state'] = 'present'
         new_result['location'] = vm.location
-        new_result['vm_size'] = result['properties']['hardwareProfile']['vmSize']
-        new_result['proximityPlacementGroup'] = result['properties'].get('proximityPlacementGroup')
+        new_result['vm_size'] = result['hardware_profile']['vm_size']
+        new_result['proximityPlacementGroup'] = result.get('proximity_placement_group')
         new_result['zones'] = result.get('zones', None)
-        os_profile = result['properties'].get('osProfile')
+        os_profile = result.get('os_profile')
         if os_profile is not None:
-            new_result['admin_username'] = os_profile.get('adminUsername')
-        image = result['properties']['storageProfile'].get('imageReference')
+            new_result['admin_username'] = os_profile.get('admin_username')
+        image = result['storage_profile'].get('image_reference')
         if image is not None:
             if image.get('publisher', None) is not None:
                 new_result['image'] = {
@@ -444,40 +499,40 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
                 }
 
         new_result['boot_diagnostics'] = {
-            'enabled': 'diagnosticsProfile' in result['properties'] and
-                       'bootDiagnostics' in result['properties']['diagnosticsProfile'] and
-                       result['properties']['diagnosticsProfile']['bootDiagnostics']['enabled'] or False,
-            'storage_uri': 'diagnosticsProfile' in result['properties'] and
-                           'bootDiagnostics' in result['properties']['diagnosticsProfile'] and
-                           result['properties']['diagnosticsProfile']['bootDiagnostics'].get('storageUri', None)
+            'enabled': 'diagnostics_profile' in result and
+                       'boot_diagnostics' in result['diagnostics_profile'] and
+                       result['diagnostics_profile']['boot_diagnostics']['enabled'] or False,
+            'storage_uri': 'diagnostics_profile' in result and
+                           'boot_diagnostics' in result['diagnostics_profile'] and
+                           result['diagnostics_profile']['boot_diagnostics'].get('storageUri', None)
         }
         if new_result['boot_diagnostics']['enabled']:
-            new_result['boot_diagnostics']['console_screenshot_uri'] = result['properties']['instanceView']['bootDiagnostics'].get('consoleScreenshotBlobUri')
-            new_result['boot_diagnostics']['serial_console_log_uri'] = result['properties']['instanceView']['bootDiagnostics'].get('serialConsoleLogBlobUri')
+            new_result['boot_diagnostics']['console_screenshot_uri'] = result['instance_view']['boot_diagnostics'].get('console_screenshot_blob_uri')
+            new_result['boot_diagnostics']['serial_console_log_uri'] = result['instance_view']['boot_diagnostics'].get('serial_console_log_blob_uri')
 
-        vhd = result['properties']['storageProfile']['osDisk'].get('vhd')
+        vhd = result['storage_profile']['os_disk'].get('vhd')
         if vhd is not None:
             url = urlparse(vhd['uri'])
             new_result['storage_account_name'] = url.netloc.split('.')[0]
             new_result['storage_container_name'] = url.path.split('/')[1]
             new_result['storage_blob_name'] = url.path.split('/')[-1]
 
-        new_result['os_disk_caching'] = result['properties']['storageProfile']['osDisk']['caching']
-        new_result['os_type'] = result['properties']['storageProfile']['osDisk']['osType']
+        new_result['os_disk_caching'] = result['storage_profile']['os_disk']['caching']
+        new_result['os_type'] = result['storage_profile']['os_disk']['os_type']
         new_result['data_disks'] = []
-        disks = result['properties']['storageProfile']['dataDisks']
+        disks = result['storage_profile']['data_disks']
         for disk_index in range(len(disks)):
             new_result['data_disks'].append({
                 'lun': disks[disk_index].get('lun'),
                 'name': disks[disk_index].get('name'),
-                'disk_size_gb': disks[disk_index].get('diskSizeGB'),
-                'managed_disk_type': disks[disk_index].get('managedDisk', {}).get('storageAccountType'),
-                'managed_disk_id': disks[disk_index].get('managedDisk', {}).get('id'),
+                'disk_size_gb': disks[disk_index].get('disk_size_gb'),
+                'managed_disk_type': disks[disk_index].get('managed_disk', {}).get('storage_account_type'),
+                'managed_disk_id': disks[disk_index].get('managed_disk', {}).get('id'),
                 'caching': disks[disk_index].get('caching')
             })
 
         new_result['network_interface_names'] = []
-        nics = result['properties']['networkProfile']['networkInterfaces']
+        nics = result['network_profile']['network_interfaces']
         for nic_index in range(len(nics)):
             new_result['network_interface_names'].append(re.sub('.*networkInterfaces/', '', nics[nic_index]['id']))
 
