@@ -34,6 +34,8 @@ options:
     tags:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
+        type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -128,6 +130,24 @@ webapps:
                         "version": "5.6"
                     }
                     ]
+        always_on:
+            description:
+                - If the app is kept loaded even when there's no traffic.
+            returned: always
+            type: bool
+            sample: true
+        min_tls_version:
+            description:
+                - The minimum TLS encryption version required for the app.
+            returned: always
+            type: str
+            sample: 1.2
+        ftps_state:
+            description:
+                - The state of the FTP/FTPS service.
+            returned: always
+            type: str
+            sample: FtpsOnly
         availability_state:
             description:
                 - Availability of this web app.
@@ -218,9 +238,9 @@ webapps:
             sample: { tag1: abc }
 '''
 try:
-    from msrestazure.azure_exceptions import CloudError
-    from msrest.polling import LROPoller
-    from azure.common import AzureMissingResourceHttpError, AzureHttpError
+    from azure.core.exceptions import ResourceNotFoundError
+    from azure.core.polling import LROPoller
+    from azure.mgmt.web.models import CsmPublishingProfileOptions
 except Exception:
     # This is handled in azure_rm_common
     pass
@@ -241,7 +261,7 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
         self.module_arg_spec = dict(
             name=dict(type='str'),
             resource_group=dict(type='str'),
-            tags=dict(type='list'),
+            tags=dict(type='list', elements='str'),
             return_publish_profile=dict(type='bool', default=False),
         )
 
@@ -285,8 +305,8 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
         result = []
 
         try:
-            item = self.web_client.web_apps.get(self.resource_group, self.name)
-        except CloudError:
+            item = self.web_client.web_apps.get(resource_group_name=self.resource_group, name=self.name)
+        except ResourceNotFoundError:
             pass
 
         if item and self.has_tags(item.tags, self.tags):
@@ -298,8 +318,8 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
     def list_by_resource_group(self):
         self.log('List web apps in resource groups {0}'.format(self.resource_group))
         try:
-            response = list(self.web_client.web_apps.list_by_resource_group(self.resource_group))
-        except CloudError as exc:
+            response = list(self.web_client.web_apps.list_by_resource_group(resource_group_name=self.resource_group))
+        except Exception as exc:
             request_id = exc.request_id if exc.request_id else ''
             self.fail("Error listing web apps in resource groups {0}, request id: {1} - {2}".format(self.resource_group, request_id, str(exc)))
 
@@ -314,7 +334,7 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
         self.log('List web apps in current subscription')
         try:
             response = list(self.web_client.web_apps.list())
-        except CloudError as exc:
+        except Exception as exc:
             request_id = exc.request_id if exc.request_id else ''
             self.fail("Error listing web apps, request id {0} - {1}".format(request_id, str(exc)))
 
@@ -332,7 +352,7 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
 
         try:
             response = self.web_client.web_apps.get_configuration(resource_group_name=resource_group, name=name)
-        except CloudError as ex:
+        except Exception as ex:
             request_id = ex.request_id if ex.request_id else ''
             self.fail('Error getting web app {0} configuration, request id {1} - {2}'.format(name, request_id, str(ex)))
 
@@ -345,7 +365,7 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
 
         try:
             response = self.web_client.web_apps.list_application_settings(resource_group_name=resource_group, name=name)
-        except CloudError as ex:
+        except Exception as ex:
             request_id = ex.request_id if ex.request_id else ''
             self.fail('Error getting web app {0} app settings, request id {1} - {2}'.format(name, request_id, str(ex)))
 
@@ -354,10 +374,10 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
     def get_publish_credentials(self, resource_group, name):
         self.log('Get web app {0} publish credentials'.format(name))
         try:
-            poller = self.web_client.web_apps.list_publishing_credentials(resource_group, name)
+            poller = self.web_client.web_apps.begin_list_publishing_credentials(resource_group_name=resource_group, name=name)
             if isinstance(poller, LROPoller):
                 response = self.get_poller_result(poller)
-        except CloudError as ex:
+        except Exception as ex:
             request_id = ex.request_id if ex.request_id else ''
             self.fail('Error getting web app {0} publishing credentials - {1}'.format(request_id, str(ex)))
         return response
@@ -368,7 +388,12 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
 
         url = None
         try:
-            content = self.web_client.web_apps.list_publishing_profile_xml_with_secrets(resource_group_name=resource_group, name=name)
+            publishing_profile_options = CsmPublishingProfileOptions(
+                format="Ftp"
+            )
+            content = self.web_client.web_apps.list_publishing_profile_xml_with_secrets(resource_group_name=resource_group,
+                                                                                        name=name,
+                                                                                        publishing_profile_options=publishing_profile_options)
             if not content:
                 return url
 
@@ -384,8 +409,8 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
                 if profile['@publishMethod'] == 'FTP':
                     url = profile['@publishUrl']
 
-        except CloudError as ex:
-            self.fail('Error getting web app {0} app settings'.format(name))
+        except Exception as ex:
+            self.fail('Error getting web app {0} app settings - {1}'.format(name, str(ex)))
 
         return url
 
@@ -397,7 +422,7 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
             app_settings = self.list_webapp_appsettings(resource_group, name)
             publish_cred = self.get_publish_credentials(resource_group, name)
             ftp_publish_url = self.get_webapp_ftp_publish_url(resource_group, name)
-        except CloudError as ex:
+        except Exception:
             pass
         return self.construct_curated_webapp(webapp=pip,
                                              configuration=site_config,
@@ -416,20 +441,20 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
         curated_output = dict()
         curated_output['id'] = webapp['id']
         curated_output['name'] = webapp['name']
-        curated_output['resource_group'] = webapp['properties']['resourceGroup']
+        curated_output['resource_group'] = webapp['resource_group']
         curated_output['location'] = webapp['location']
-        curated_output['plan'] = webapp['properties']['serverFarmId']
+        curated_output['plan'] = webapp['server_farm_id']
         curated_output['tags'] = webapp.get('tags', None)
 
         # important properties from output. not match input arguments.
-        curated_output['app_state'] = webapp['properties']['state']
-        curated_output['availability_state'] = webapp['properties']['availabilityState']
-        curated_output['default_host_name'] = webapp['properties']['defaultHostName']
-        curated_output['host_names'] = webapp['properties']['hostNames']
-        curated_output['enabled'] = webapp['properties']['enabled']
-        curated_output['enabled_host_names'] = webapp['properties']['enabledHostNames']
-        curated_output['host_name_ssl_states'] = webapp['properties']['hostNameSslStates']
-        curated_output['outbound_ip_addresses'] = webapp['properties']['outboundIpAddresses']
+        curated_output['app_state'] = webapp['state']
+        curated_output['availability_state'] = webapp['availability_state']
+        curated_output['default_host_name'] = webapp['default_host_name']
+        curated_output['host_names'] = webapp['host_names']
+        curated_output['enabled'] = webapp['enabled']
+        curated_output['enabled_host_names'] = webapp['enabled_host_names']
+        curated_output['host_name_ssl_states'] = webapp['host_name_ssl_states']
+        curated_output['outbound_ip_addresses'] = webapp['outbound_ip_addresses']
 
         # curated site_config
         if configuration:
@@ -458,6 +483,10 @@ class AzureRMWebAppInfo(AzureRMModuleBase):
                 if len(tmp) == 2:
                     curated_output['frameworks'].append({'name': tmp[0].lower(), 'version': tmp[1]})
 
+            curated_output['always_on'] = configuration.get('always_on')
+            curated_output['ftps_state'] = configuration.get('ftps_state')
+            curated_output['min_tls_version'] = configuration.get('min_tls_version')
+
         # curated app_settings
         if app_settings and app_settings.get('properties', None):
             curated_output['app_settings'] = dict()
