@@ -1,9 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# Copyright: (c) 2016, Hiroaki Nakamura <hnakamur@gmail.com>
-# Copyright: (c) 2020, Frank Dornheim <dornheim@posteo.de>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# Copyright (c) 2016, Hiroaki Nakamura <hnakamur@gmail.com>
+# Copyright (c) 2020, Frank Dornheim <dornheim@posteo.de>
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -15,25 +16,40 @@ short_description: Manage LXD profiles
 description:
   - Management of LXD profiles
 author: "Hiroaki Nakamura (@hnakamur)"
+extends_documentation_fragment:
+  - community.general.attributes
+attributes:
+    check_mode:
+        support: none
+    diff_mode:
+        support: none
 options:
     name:
         description:
           - Name of a profile.
         required: true
         type: str
+    project:
+        description:
+         - 'Project of a profile.
+           See U(https://documentation.ubuntu.com/lxd/en/latest/projects/).'
+        type: str
+        required: false
+        version_added: 4.8.0
     description:
         description:
           - Description of the profile.
         type: str
     config:
         description:
-          - 'The config for the container (e.g. {"limits.memory": "4GB"}).
-            See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#patch-3)'
+          - 'The config for the instance (e.g. {"limits.memory": "4GB"}).
+            See U(https://documentation.ubuntu.com/lxd/en/latest/api/#/profiles/profile_get).'
           - If the profile already exists and its "config" value in metadata
             obtained from
             GET /1.0/profiles/<name>
-            U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#get-19)
-            are different, they this module tries to apply the configurations.
+            U(https://documentation.ubuntu.com/lxd/en/latest/api/#/profiles/profile_get)
+            are different, then this module tries to apply the configurations
+            U(https://documentation.ubuntu.com/lxd/en/latest/api/#/profiles/profile_put).
           - Not all config values are supported to apply the existing profile.
             Maybe you need to delete and recreate a profile.
         required: false
@@ -42,14 +58,14 @@ options:
         description:
           - 'The devices for the profile
             (e.g. {"rootfs": {"path": "/dev/kvm", "type": "unix-char"}).
-            See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#patch-3)'
+            See U(https://documentation.ubuntu.com/lxd/en/latest/api/#/profiles/profile_get).'
         required: false
         type: dict
     new_name:
         description:
           - A new name of a profile.
           - If this parameter is specified a profile will be renamed to this name.
-            See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#post-11)
+            See U(https://documentation.ubuntu.com/lxd/en/latest/api/#/profiles/profile_post).
         required: false
         type: str
     merge_profile:
@@ -129,6 +145,19 @@ EXAMPLES = '''
             parent: br0
             type: nic
 
+# An example for creating a profile in project mytestproject
+- hosts: localhost
+  connection: local
+  tasks:
+    - name: Create a profile
+      community.general.lxd_profile:
+        name: testprofile
+        project: mytestproject
+        state: present
+        config: {}
+        description: test profile in project mytestproject
+        devices: {}
+
 # An example for creating a profile via http connection
 - hosts: localhost
   connection: local
@@ -202,12 +231,13 @@ actions:
   description: List of actions performed for the profile.
   returned: success
   type: list
-  sample: '["create"]'
+  sample: ["create"]
 '''
 
 import os
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.general.plugins.module_utils.lxd import LXDClient, LXDClientException
+from ansible.module_utils.six.moves.urllib.parse import urlencode
 
 # ANSIBLE_LXD_DEFAULT_URL is a default value of the lxd endpoint
 ANSIBLE_LXD_DEFAULT_URL = 'unix:/var/lib/lxd/unix.socket'
@@ -225,13 +255,14 @@ CONFIG_PARAMS = [
 
 class LXDProfileManagement(object):
     def __init__(self, module):
-        """Management of LXC containers via Ansible.
+        """Management of LXC profiles via Ansible.
 
         :param module: Processed Ansible Module.
         :type module: ``object``
         """
         self.module = module
         self.name = self.module.params['name']
+        self.project = self.module.params['project']
         self._build_config()
         self.state = self.module.params['state']
         self.new_name = self.module.params.get('new_name', None)
@@ -272,10 +303,10 @@ class LXDProfileManagement(object):
                 self.config[attr] = param_val
 
     def _get_profile_json(self):
-        return self.client.do(
-            'GET', '/1.0/profiles/{0}'.format(self.name),
-            ok_error_codes=[404]
-        )
+        url = '/1.0/profiles/{0}'.format(self.name)
+        if self.project:
+            url = '{0}?{1}'.format(url, urlencode(dict(project=self.project)))
+        return self.client.do('GET', url, ok_error_codes=[404])
 
     @staticmethod
     def _profile_json_to_module_state(resp_json):
@@ -307,14 +338,20 @@ class LXDProfileManagement(object):
                         changed=False)
 
     def _create_profile(self):
+        url = '/1.0/profiles'
+        if self.project:
+            url = '{0}?{1}'.format(url, urlencode(dict(project=self.project)))
         config = self.config.copy()
         config['name'] = self.name
-        self.client.do('POST', '/1.0/profiles', config)
+        self.client.do('POST', url, config)
         self.actions.append('create')
 
     def _rename_profile(self):
+        url = '/1.0/profiles/{0}'.format(self.name)
+        if self.project:
+            url = '{0}?{1}'.format(url, urlencode(dict(project=self.project)))
         config = {'name': self.new_name}
-        self.client.do('POST', '/1.0/profiles/{0}'.format(self.name), config)
+        self.client.do('POST', url, config)
         self.actions.append('rename')
         self.name = self.new_name
 
@@ -332,7 +369,7 @@ class LXDProfileManagement(object):
         )
 
     def _merge_dicts(self, source, destination):
-        """Merge Dictionarys
+        """Merge Dictionaries
 
         Get a list of filehandle numbers from logger to be handed to
         DaemonContext.files_preserve
@@ -421,11 +458,17 @@ class LXDProfileManagement(object):
             config = self._generate_new_config(config)
 
         # upload config to lxd
-        self.client.do('PUT', '/1.0/profiles/{0}'.format(self.name), config)
+        url = '/1.0/profiles/{0}'.format(self.name)
+        if self.project:
+            url = '{0}?{1}'.format(url, urlencode(dict(project=self.project)))
+        self.client.do('PUT', url, config)
         self.actions.append('apply_profile_configs')
 
     def _delete_profile(self):
-        self.client.do('DELETE', '/1.0/profiles/{0}'.format(self.name))
+        url = '/1.0/profiles/{0}'.format(self.name)
+        if self.project:
+            url = '{0}?{1}'.format(url, urlencode(dict(project=self.project)))
+        self.client.do('DELETE', url)
         self.actions.append('delete')
 
     def run(self):
@@ -469,6 +512,9 @@ def main():
                 type='str',
                 required=True
             ),
+            project=dict(
+                type='str',
+            ),
             new_name=dict(
                 type='str',
             ),
