@@ -1,7 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Copyright 2016 Tomas Karasek <tom.to.the.k@gmail.com>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -10,11 +11,18 @@ __metaclass__ = type
 DOCUMENTATION = '''
 ---
 module: packet_sshkey
-short_description: Create/delete an SSH key in Packet host.
+short_description: Create/delete an SSH key in Packet host
 description:
      - Create/delete an SSH key in Packet host.
      - API is documented at U(https://www.packet.net/help/api/#page:ssh-keys,header:ssh-keys-ssh-keys-post).
 author: "Tomas Karasek (@t0mk) <tom.to.the.k@gmail.com>"
+extends_documentation_fragment:
+  - community.general.attributes
+attributes:
+  check_mode:
+    support: none
+  diff_mode:
+    support: none
 options:
   state:
     description:
@@ -24,7 +32,7 @@ options:
     type: str
   auth_token:
     description:
-    - Packet API token. You can also supply it in env var C(PACKET_API_TOKEN).
+    - Packet API token. You can also supply it in environment variable E(PACKET_API_TOKEN).
     type: str
   label:
     description:
@@ -83,7 +91,7 @@ RETURN = '''
 changed:
     description: True if a sshkey was created or removed.
     type: bool
-    sample: True
+    sample: true
     returned: always
 sshkeys:
     description: Information about sshkeys that were created/removed.
@@ -168,7 +176,7 @@ def get_sshkey_selector(module):
             return k.key == select_dict['key']
         else:
             # if key string not specified, all the fields must match
-            return all([select_dict[f] == getattr(k, f) for f in select_dict])
+            return all(select_dict[f] == getattr(k, f) for f in select_dict)
     return selector
 
 
@@ -226,11 +234,11 @@ def main():
             state=dict(choices=['present', 'absent'], default='present'),
             auth_token=dict(default=os.environ.get(PACKET_API_TOKEN_ENV_VAR),
                             no_log=True),
-            label=dict(type='str', aliases=['name'], default=None),
-            id=dict(type='str', default=None),
-            fingerprint=dict(type='str', default=None),
-            key=dict(type='str', default=None, no_log=True),
-            key_file=dict(type='path', default=None),
+            label=dict(type='str', aliases=['name']),
+            id=dict(type='str'),
+            fingerprint=dict(type='str'),
+            key=dict(type='str', no_log=True),
+            key_file=dict(type='path'),
         ),
         mutually_exclusive=[
             ('label', 'id'),
